function[mc]=MCA(x,y)
 %x=Observed;
 %y=Modeled;
 %Q_sq: Value of the metric Q-squared
 %How to call the function:
 %x=rand(100,1);
 %y=x*rand();
 %[Q_sq]=Q_SQUARED(x,y);

  
 n=length(x); %sample size of the observed data
 
%=============================================
%INITIALIZATION
%*********************************************
Dx=zeros(n,1); %for transformed observed series
Dy=zeros(n,1); %for transformed modeled series
ux=zeros(n,1); %number of exceedance - observed series
uy=zeros(n,1); %number of exceedance - modeled series
wx=zeros(n,1); %number of times a data point appears in observed series
wy=zeros(n,1); %number of times a data point appears in modeled series
h=zeros(n,1);  %Penalty-based series derived from modeled data
A=zeros(n,1);
B=zeros(n,1);
C=zeros(n,1);
D=zeros(n,1);

%COMPUTING THE PARAMETRIC COMPONENT OF THE MODEL EFFICIENCY
%**********************************************************
x_mean=mean(x); % Mean of observed series

%Penalty-based series derived from y or modeled series
%**********************************************************
for i=1:n
    if (x(i,1)<0 && y(i,1)>=0) || (x(i,1)>0 && y(i,1)<=0) 
        h(i,1)=0;
    else
        h(i,1)=y(i,1);
    end
end
%=========================================================

for i=1:n
       A(i,1)= (min(x(i,1),h(i,1))-2*x_mean)^2;
       B(i,1)= (max(x(i,1),h(i,1))-2*x_mean)^2; 
       C(i,1)= min (A(i,1),B(i,1));
       D(i,1)= max (A(i,1),B(i,1));
end

if (sum(D)==0 || sum(h)==0);
    beta1=0;
else
    beta1=(sum(C)/sum(D));
end

%TRANSFORMATION OF OBSERVED SERIES
%***********************************
for i=1:n
    wx(i)=sum(x==x(i));  %counting how many times a data point x(i) appears in observed series X
    ux(i)=sum(x>x(i));   %counting how many times a given value x(i) is exceeded from an array X
    Dx(i)=n-wx(i)-2*ux(i);
end    
     
%TRANSFORMATION OF MODELED SERIES
%*********************************
for i=1:n
    wy(i)=sum(y==y(i));  %counting how many times a data point y(i) appears in from an array y
    uy(i)=sum(y>y(i));  %counting how many times a given value y(i) is exceeded from an array y
    Dy(i)=n-wy(i)-2*uy(i);  %this is the transformed modeled series
end

%Computing non-parametric trend slope and Q-squared
%*****************************************************************
if (sum(Dx.^2)==0 || sum(Dy.^2)==0);
    rc=0;
else
    rc=1*sum(Dx.*Dy)/sqrt(sum(Dx.^2)*sum(Dy.^2));
end

mc=(rc)^2*beta1^2;

end